import { Construct } from "constructs";
import { Bucket } from "aws-cdk-lib/aws-s3";
import { OriginAccessIdentity } from "aws-cdk-lib/aws-cloudfront";
import { BucketDeployment, ISource } from "aws-cdk-lib/aws-s3-deployment";
import { Duration, RemovalPolicy } from "aws-cdk-lib";
import { ExtendedConstruct, ExtendedConstructProps } from "../../aws-cdk";
/**
 * Properties for CloudFrontBucket.
 */
export interface CloudFrontBucketProps extends ExtendedConstructProps {
    /**
     * Policy to apply when the bucket is removed from this stack.
     * @default RemovalPolicy.RETAIN
     */
    readonly removalPolicy?: RemovalPolicy;
    /**
     * Whether all objects should be automatically deleted when the bucket is removed from the stack or when the stack is deleted.
     * Requires the removalPolicy to be set to RemovalPolicy.DESTROY. Default is false.
     *
     * @default false
     */
    readonly autoDeleteObjects?: boolean;
    /**
     * Whether this bucket should have versioning turned on or not. Default is false.
     *
     * @default false
     */
    readonly versioned?: boolean;
    /**
     * Whether this bucket should have transfer acceleration turned on or not. Default is false.
     *
     * @default false
     */
    readonly transferAcceleration?: boolean;
}
/**
 * Simple Construct for creating buckets that will be accessed directly by CloudFront as an Origin.
 */
export declare class CloudFrontBucket extends ExtendedConstruct {
    readonly bucket: Bucket;
    readonly bucketName: string;
    readonly bucketArn: string;
    readonly originAccessIdentity: OriginAccessIdentity;
    readonly originAccessIdentityId: string;
    constructor(scope: Construct, id: string, props: CloudFrontBucketProps);
    /**
     * Helper method to deploy local assets to the created bucket. Ths function assumes
     * CloudFront invalidation requests will be sent for mutable files to serve new content.
     * For more complicated deployments, use BucketDeployment directly.
     *
     * @param path the path to the local assets
     * @param maxAge the length of time to browsers will cache files; default is Duration.minutes(15)
     * @param sMaxAge the length of time CloudFront will cache files; default is Duration.days(7)
     * @param prune true to prune old files; default is false
     */
    deployPath(path: string, maxAge?: Duration, sMaxAge?: Duration, prune?: boolean): BucketDeployment;
    /**
     * Helper method to assets to the created bucket. This function assumes CloudFront invalidation
     * requests will be sent for mutable files to serve new content.
     * For more complicated deployments, use BucketDeployment directly.
     *
     * @param source the source to deploy
     * @param maxAge the length of time to browsers will cache files; default is Duration.minutes(15)
     * @param sMaxAge the length of time CloudFront will cache files; default is Duration.days(7)
     * @param prune true to prune old files; default is false
     */
    deploySource(source: ISource, maxAge?: Duration, sMaxAge?: Duration, prune?: boolean): BucketDeployment;
}
